//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : flash.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmiodaDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

int _tmain(int argc, _TCHAR* argv[])
{
    unsigned int portState[6] = { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };  // define all as outputs
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : flash\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing PCM-MIO device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("PCM-MIO device opened.\n");
    }

    dllReturn = DioSetIoMask(DEVICE, portState);

    if (dllReturn)
    {
        printf("Error setting I/O mask.\n");
        exit(dllReturn);
    }

    printf("Flashing bits ...\n");

    for (int bit = 0; bit < 48; bit++)
    {
       dllReturn = DioSetBit(DEVICE, bit);

       if (dllReturn)
       {
           printf("\nError setting bit %d.\n", bit);
           break;
       }

       Sleep(200);

       if (DioClearBit(DEVICE, bit))
       {
           printf("\nError clearing bit %d.\n", bit);
           break;
       }

       Sleep(200);
    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
