//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : pcmmiodaDLL.h
//
//	Project	 : PCM-MIO-DA Windows DLL
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release of DLL	
//
//****************************************************************************

#ifndef _PCMMIODA_DLL_H_
#define _PCMMIODA_DLL_H_

#if defined DLL_EXPORT
#define DECLDIR __declspec(dllexport)
#else
#define DECLDIR __declspec(dllimport)
#endif  // DLL_EXPORT

extern "C"
{
    DECLDIR int InitializeSession(unsigned int device);
    DECLDIR int CloseSession(unsigned int device);

    // DIO functions
    DECLDIR int DioResetDevice(unsigned int device);
    DECLDIR int DioSetIoMask(unsigned int device, unsigned int *portState);
    DECLDIR int DioGetIoMask(unsigned int device, unsigned int *portState);
    DECLDIR int DioReadAllPorts(unsigned int device, unsigned int *readValueArray);
    DECLDIR int DioReadPort(unsigned int device, int port, unsigned int *readValue);
    DECLDIR int DioReadBit(unsigned int device, int bit, unsigned int *bitValue);
    DECLDIR int DioSetBit(unsigned int device, int bit);
    DECLDIR int DioClearBit(unsigned int device, int bit);
    DECLDIR int DioWritePort(unsigned int device, int port, unsigned int writeValue);
    DECLDIR int DioWriteBit(unsigned int device, int bit, unsigned int bitValue);
    DECLDIR int DioEnableInterrupt(unsigned int device, int bit, int edge);
    DECLDIR int DioDisableInterrupt(unsigned int device, int bit);
    DECLDIR int DioGetInterrupt(unsigned int device, unsigned int *irqArray);
    DECLDIR int DioWaitForInterrupt(unsigned int device, unsigned int *irqArray, unsigned long timeout);
    DECLDIR int DioLockPort(unsigned int device, int port);
    DECLDIR int DioUnlockPort(unsigned int device, int port);

    // DAC functions
    DECLDIR int DacSetChannelVoltage(unsigned int device, unsigned int channel, float voltage);
    DECLDIR int DacSetChannelOutput(unsigned int device, unsigned int channel, unsigned short code);
    DECLDIR int DacSetChannelSpan(unsigned int device, unsigned int channel, unsigned short span);
    DECLDIR int DacBufferedVoltage(unsigned int device, unsigned short *chanBuf, float *voltBuf);
    DECLDIR int DacEnableInterrupt(unsigned int device, unsigned int channel);
    DECLDIR int DacDisableInterrupt(unsigned int device, unsigned int channel);
    DECLDIR int DacWaitForUpdate(unsigned int device, unsigned int channel, unsigned short code, unsigned long timeout);
    DECLDIR int DacWriteCommand(unsigned int device, unsigned int channel, unsigned int dacCommand);
    DECLDIR int DacWriteData(unsigned int device, unsigned int channel, unsigned int dacData);
    DECLDIR int DacWaitForReady(unsigned int device, unsigned int channel);
}

typedef enum {
    SUCCESS = 0,
    DRIVER_ERROR,
    ACCESS_ERROR,
    INVALID_HANDLE,
    INVALID_PARAMETER,
    TIMEOUT_ERROR
} ErrorCodes;

typedef enum {
    FALLING_EDGE = 0,
    RISING_EDGE
} IrqEdge;

typedef enum {
    DAC_A = 0,
    DAC_B = 2,
    DAC_C = 4,
    DAC_D = 6,
    DAC_ALL = 15,
} DacAddress;

typedef enum {
    DAC_SPAN_UNI5 = 0,
    DAC_SPAN_UNI10,
    DAC_SPAN_BI5,
    DAC_SPAN_BI10,
    DAC_SPAN_BI2,
    DAC_SPAN_BI7
} DacSpan;

#endif  // _PCMMIO_DLL_H_
